package App::colcount ;  
our $VERSION = '0.030' ; 
our $DATE = '2024-03-15T17:50+09:00' ; 

=encoding utf8

=head1 NAME

App::colcount -- 各行について、カラムの数を数えたり、条件を満たすカラムの数を数えたりする。

=head1 SYNOPSIS

This module provides a Unix-like command `F<colcount>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

1. App::freq  :  The module which provides the command `freq'. 
                   You may use as ` colcount somefile | freq -: '.

2. App::collen  : similar functions but with different command options.

=head1 AUTHOR

Toshiyuki Shimono (Advanced Collaborative Research Organization for Smart Society, Waseda University)

=cut

1 ;
